# frozen_string_literal: true

module DirectApi
  # AdGroups methods
  class AdgroupsAdapter

    ADGROUP_FIELD_NAMES = %w[Id CampaignId Status Name RegionIds
                             NegativeKeywords TrackingParams Type].freeze
    MOBILE_APP_ADGROUP_FIELD_NAMES = %w[StoreUrl TargetDeviceType TargetCarrier
                                        TargetOperatingSystemVersion AppIconModeration
                                        AppAvailabilityStatus AppOperatingSystemType].freeze
    DYNAMIC_TEXT_ADGROUP_FIELD_NAMES = %w[DomainUrl].freeze

    def build_request(client_settings, params = {})
      [:adgroups, build(params).merge(client_settings)]
    end

    private

    def build(options = {})
      {
        method: :get,
        params: {
          SelectionCriteria: options[:params],
          FieldNames: options.fetch(:field_names, ADGROUP_FIELD_NAMES),
          MobileAppAdGroupFieldNames: options.fetch(:mobile_app_adgroup_field_names,
                                                    MOBILE_APP_ADGROUP_FIELD_NAMES),
          DynamicTextAdGroupFieldNames: options.fetch(:dynamic_text_adgroup_field_names,
                                                      DYNAMIC_TEXT_ADGROUP_FIELD_NAMES)
        }
      }
    end

  end
end
