# frozen_string_literal: true

module DirectApi
  # Ads methods
  class AdsAdapter

    AD_FIELD_NAMES = %w[AdCategories AgeLabel AdGroupId CampaignId Id State Status
                        StatusClarification Type Subtype].freeze
    TEXT_AD_FIELD_NAMES = %w[Title Text Href Mobile DisplayDomain DisplayUrlPath
                             DisplayUrlPathModeration VCardId VCardModeration SitelinkSetId
                             SitelinksModeration AdImageHash AdImageModeration AdExtensions].freeze
    MOBILE_APP_AD_FIELD_NAMES = %w[Title Text Features Action AdImageHash
                                   AdImageModeration TrackingUrl].freeze
    DYNAMIC_TEXT_AD_FIELD_NAMES = %w[Text VCardId VCardModeration SitelinkSetId SitelinksModeration
                                     AdImageHash AdImageModeration AdExtensions].freeze
    TEXT_IMAGE_AD_FIELD_NAMES = %w[AdImageHash Href].freeze
    MOBILE_APP_IMAGE_AD_FIELD_NAMES = %w[AdImageHash TrackingUrl].freeze

    def build_request(client_settings, params = {})
      [:ads, build(params).merge(client_settings)]
    end

    private

    def build(options = {})
      {
        method: :get,
        params: extract_options(options)
      }
    end

    def extract_options(p)
      {
        SelectionCriteria: p[:params],
        FieldNames: p.fetch(:field_names, AD_FIELD_NAMES),
        TextAdFieldNames: p.fetch(:text_ad_field_names, TEXT_AD_FIELD_NAMES),
        MobileAppAdFieldNames: p.fetch(:mobile_app_ad_field_names, MOBILE_APP_AD_FIELD_NAMES),
        DynamicTextAdFieldNames: p.fetch(:dynamic_text_ad_field_names, DYNAMIC_TEXT_AD_FIELD_NAMES),
        TextImageAdFieldNames: p.fetch(:text_image_ad_field_names, TEXT_IMAGE_AD_FIELD_NAMES),
        MobileAppImageAdFieldNames:
          p.fetch(:mobile_app_image_ad_field_names, MOBILE_APP_IMAGE_AD_FIELD_NAMES)
      }
    end

  end
end
