# frozen_string_literal: true

module DirectApi
  # Campaigns methods
  class CampaignsAdapter

    CAMPAIGN_FIELD_NAMES = %w[BlockedIps ExcludedSites Currency DailyBudget Notification EndDate
                              Funds ClientInfo Id Name NegativeKeywords RepresentedBy StartDate
                              Statistics State Status StatusPayment StatusClarification SourceId
                              TimeTargeting TimeZone Type].freeze
    TEXT_CAMPAIGN_FIELD_NAMES = %w[CounterIds RelevantKeywords Settings BiddingStrategy].freeze
    MOBILE_APP_CAMPAIGN_FIELD_NAMES = %w[Settings BiddingStrategy].freeze
    DYNAMIC_TEXT_CAMPAIGN_FIELD_NAMES = %w[CounterIds Settings BiddingStrategy].freeze

    def build_request(client_settings, params = {})
      [:campaigns, build(params).merge(client_settings)]
    end

    private

    def build(options = {})
      {
        method: :get,
        params: extract_options(options)
      }
    end

    def extract_options(p)
      {
        SelectionCriteria: p[:params],
        FieldNames: p.fetch(:field_names, CAMPAIGN_FIELD_NAMES),
        TextCampaignFieldNames: p.fetch(:text_campaign_field_names, TEXT_CAMPAIGN_FIELD_NAMES),
        MobileAppCampaignFieldNames:
          p.fetch(:mobile_app_campaign_field_names, MOBILE_APP_CAMPAIGN_FIELD_NAMES),
        DynamicTextCampaignFieldNames:
          p.fetch(:dynamic_text_campaign_field_names, DYNAMIC_TEXT_CAMPAIGN_FIELD_NAMES)
      }
    end

  end
end
