# frozen_string_literal: true

module DirectApi
  # Yandex Direct request module
  module Request

    API_URI = 'https://api.direct.yandex.com/json/v5/'
    SANDBOX_API_URI = 'https://api-sandbox.direct.yandex.com/json/v5/'

    module_function

    def process(path, params = {})
      response_parser.parse(
        make_request(path, params).to_s
      )
    end

    def make_request(path, params = {})

      RestClient.post(*build(path, params))
    rescue RestClient::Unauthorized,
           RestClient::Forbidden,
           RestClient::BadRequest,
           RestClient::ResourceNotFound => e
      raise DirectApi::RequestError, e.message
    rescue SocketError => e
      raise DirectApi::ConnectionError, e.message

    end

    def build(path, params)
      headers = {}
      path = get_uri(params.delete(:sandbox)) + path.to_s

      headers['Accept-Language'] = params.delete(:locale)
      headers['Client-Login'] = params.delete(:client_login)
      headers['Authorization'] = "Bearer #{params.delete(:token)}"

      [path, params.to_json, headers]
    end

    def get_uri(sandbox)
      sandbox ? SANDBOX_API_URI : API_URI
    end

    def response_parser
      Response
    end

  end
end
