# frozen_string_literal: true

module DirectApi
  # Yandex Direct response parser
  module Response

    module_function

    def parse(response)
      if response.is_a?(Hash)
        lower_keys(response)
      elsif response.is_a?(Array)
        response.map { |r| parse(r) }
      elsif response.is_a?(String)
        parse(json_parse(response))
      else
        response
      end
    rescue JSON::ParserError
      response
    end

    def json_parse(response)
      JSON.parse(response)
    end

    def lower_keys(h)
      h.each_with_object({}) do |(key, value), memo|
        memo[key.underscore] = parse(value)
      end
    end

  end
end
