# frozen_string_literal: true

module DirectApi
  # Direct Api session object
  class Session

    def initialize(api_data)
      @api_data = api_data
    end

    def campaigns(token, client_login, params = {})
      process_request(token, client_login, campaigns_adapter, params)
    end

    def adgroups(token, client_login, params = {})
      process_request(token, client_login, adgroups_adapter, params)
    end

    def ads(token, client_login, params = {})
      process_request(token, client_login, ads_adapter, params)
    end

    private

    attr_reader :api_data

    def process_request(token, client_login, adapter, params)
      requester.process(*adapter.build_request(client_settings(token, client_login), params))
    end

    def client_settings(token, client_login)
      {
        token: token,
        client_login: client_login,
        sandbox: api_data[:sandbox],
        locale: api_data[:locale]
      }
    end

    def campaigns_adapter
      @campaigns_adapter ||= CampaignsAdapter.new
    end

    def adgroups_adapter
      @adgroups_adapter ||= AdgroupsAdapter.new
    end

    def ads_adapter
      @ads_adapter ||= AdsAdapter.new
    end

    def requester
      Request
    end

  end
end
